<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+95"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+157"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+152"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+81"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Осевая</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+164"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+154"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+156"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+117"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+121"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+97"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+84"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+90"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+78"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+108"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+90"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+82"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Радиус</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Начальный угол</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Конечный угол</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Обратный</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Диаметр</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+7"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Общая длина</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Угол развёртки</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+3"/>
        <source>Area</source>
        <translation>Область</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Общая площадь</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+95"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+101"/>
        <source>Tag</source>
        <translation>Тег</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Подсказка</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <source>Circumference</source>
        <translation>Периметр</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translation>Размерная линия</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translation>Точка расширения 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translation>Точка расширения 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translation>Линия 1 Начало</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>Линия 1 Конец</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>Линия 2 Начало</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>Линия 2 Конец</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Размерная дуга</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translation>Точка хорды</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translation>Дальняя точка хорды</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-11"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Начало координат</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Ордината</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translation>Определяющая точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translation>Конечная точка полки-выноски</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+172"/>
        <source>Dimension Angle</source>
        <translation>Размерный угол</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Допуск</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translation>Верхний предел</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translation>Нижний предел</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translation>Определяющая точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Положение текста</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Text Rotation</source>
        <translation>Вращение текста</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flip First Arrow</source>
        <translation>Кувыркающаяся первая стрелка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Кувыркающаяся вторая стрелка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Фиксированная удлинительная линия</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Длина удлинительной линии</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Автометка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Измеренное значение</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Block Name</source>
        <translation>Имя блока</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Позиция автометки</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translation>Главная точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Соотношение</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Начальный параметр</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Конечный параметр</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Начальная точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Конечная точка</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-10"/>
        <source>Solid</source>
        <translation>Сплошной</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Winding</source>
        <translation>Намотка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alpha</source>
        <translation>Альфа</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Рисунок</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Из объекта</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-13"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Угол</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location line="-208"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Вершина</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translation>Коэф. ширины</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translation>Коэф. высоты</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Угасание</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-5"/>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Spline</source>
        <translation>Сплайн</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Блок стрелок</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Шаблон ломаной</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Закрытый</translation>
    </message>
    <message>
        <location line="+4"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+0"/>
        <source>Bulge</source>
        <translation>Выпуклость</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Начальная ширина</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Конечная ширина</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Глобальная ширина</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Ориентация</translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <source>Base Angle</source>
        <translation>Базовый угол</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 1</source>
        <translation>Размер 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 2</source>
        <translation>Размер 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Глобальная Z</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Точка 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Точка 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>Точка 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>Точка 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Закрытая периодичность</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Градусы</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translation>Контрольная точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translation>Узловая точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Вектор кельтского узла</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Кельтский узел</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Использовать начальный тангенс</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Начальный тангенс</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Использовать конечный тангенс</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Конечный тангенс</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Базовая точка</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Вторая точка</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Направление вектора</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Фиксированный угол</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="-3"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Невидимый</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+190"/>
        <source>Arc Symbol Type</source>
        <translation>Тип символа дуги</translation>
    </message>
    <message>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-5"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction</source>
        <translation>Направление</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle Point</source>
        <translation>Средняя точка</translation>
    </message>
    <message>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <source>Frame</source>
        <translation>Рама</translation>
    </message>
</context>
</TS>
